%define major		68
%define libname 	%mklibname icu %{major}
%define develname 	%mklibname icu -d

%define dataname	%{name}%{major}-data

%define tarballver	%(echo %version|tr '.' '_')
%define dashver		%(echo %version|tr '.' '-')

# re-enable when upgrading this package to a new version
%define with_tests 1

Summary:	International Components for Unicode
Name:		icu
Epoch:		1
Version:	68.2
%define subrel 1
Release:	%mkrel 1
License:	Unicode
Group:		System/Libraries
URL:		http://site.icu-project.org/
Source0:	https://github.com/unicode-org/icu/releases/download/release-%{dashver}/icu4c-%{tarballver}-src.tgz
Patch0:		icu-50.1-disable-renaming.patch
Patch1:		CVE-2021-30535.patch
BuildRequires:	doxygen
Requires:	%{libname} = %{epoch}:%{version}

%description
The International Components for Unicode (ICU) libraries provide robust and
full-featured Unicode services on a wide variety of platforms. ICU supports
the most current version of the Unicode standard, and they provide support
for supplementary Unicode characters (needed for GB 18030 repertoire support).

As computing environments become more heterogeneous, software portability
becomes more important. ICU lets you produce the same results across all the
various platforms you support, without sacrificing performance. It offers
great flexibility to extend and customize the supplied services, which
include:

  * Text: Unicode text handling, full character properties and character set
    conversions (500+ codepages)
  * Analysis: Unicode regular expressions; full Unicode sets; character, word
    and line boundaries
  * Comparison: Language sensitive collation and searching
  * Transformations: normalization, upper/lowercase, script transliterations
    (50+ pairs)
  * Locales: Comprehensive locale data (230+) and resource bundle architecture
  * Complex Text Layout: Arabic, Hebrew, Indic and Thai
  * Time: Multi-calendar and time zone
  * Formatting and Parsing: dates, times, numbers, currencies, messages and
    rule based

%package -n	%{dataname}
Summary:	Shared data for the International Components for Unicode
Group:		System/Libraries
BuildArch:	noarch

%description -n	%{dataname}
Shared data for the International Components for Unicode.

%package	doc
Summary:	Documentation for the International Components for Unicode
Group:		System/Libraries
Requires:	%{name}
BuildArch:	noarch

%description	doc
Documentation for the International Components for Unicode.

%package -n	%{libname}
Summary:	Libraries for the International Components for Unicode
Group:		System/Libraries
Requires:	%{dataname} = %{epoch}:%{version}-%{release}

%description -n	%{libname}
Libraries for the International Components for Unicode.

%package -n	%{develname}
Summary:	Development files for the International Components for Unicode
Group:		Development/Other
Requires:	%{libname} = %{epoch}:%{version}-%{release}
Provides:	%{name}%{major}-devel = %{epoch}:%{version}-%{release}
Provides:	%{name}-devel = %{epoch}:%{version}-%{release}
Provides:	lib%{name}-devel = %{epoch}:%{version}-%{release}

%description -n	%{develname}
Development files and headers for the International Components for Unicode.

%prep
%setup -q -n %{name}
%autopatch -p1

%build
pushd source
%configure \
	--with-library-bits=64else32 \
	--with-data-packaging=archive \
	--disable-renaming \
	--disable-samples
mkdir -p data/out/tmp
# fix test failures
sed -i.testdata -r -e 's#/genrb#/genrb $(ICU_DATA_OPT)#' test/testdata/rules.mk
%__make
%__make doc
popd

%if %{with_tests}
%check
pushd source
export LC_ALL=C LANG=en
%ifarch aarch64
make check ||:
%else
make check
%endif
popd
%endif

%install
%make_install -C source

%files
%{_bindir}/*
%exclude %{_bindir}/icu-config
%{_sbindir}/*

%files -n %{dataname}
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/%{version}
%{_datadir}/%{name}/%{version}/icudt%{major}l.dat

%files doc
%doc readme.html source/doc/html/*
%{_mandir}/man1/*
%{_mandir}/man8/*

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%{_bindir}/icu-config
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%dir %{_includedir}/unicode
%{_includedir}/unicode/*
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/%{version}
%{_libdir}/%{name}/%{version}/Makefile.inc
%{_libdir}/%{name}/%{version}/pkgdata.inc
%{_libdir}/%{name}/Makefile.inc
%{_libdir}/%{name}/current
%{_libdir}/%{name}/pkgdata.inc
%{_datadir}/%{name}/%{version}/config
%{_datadir}/%{name}/%{version}/install-sh
%{_datadir}/%{name}/%{version}/LICENSE
%{_datadir}/%{name}/%{version}/mkinstalldirs


%changelog
* Mon Sep 27 2021 ns80 <ns80> 1:68.2-1.1.mga8
+ Revision: 1746665
- backport upstream patch for CVE-2021-30535 (mga#29491)

* Tue Dec 29 2020 akien <akien> 1:68.2-1.mga8
+ Revision: 1664728
- Version 68.2, bugfix, fixes at least one crash

* Mon Nov 30 2020 luigiwalser <luigiwalser> 1:68.1-1.mga8
+ Revision: 1650945
- 68.1
- library major is now 68

* Wed Jul 01 2020 wally <wally> 1:67.1-1.mga8
+ Revision: 1600999
- new version 67.1
- new lib major 67
- drop multiarch support

* Sat Apr 04 2020 wally <wally> 1:66.1-1.mga8
+ Revision: 1564423
- new version 66.1
- new lib major 66

* Sun Feb 16 2020 umeabot <umeabot> 1:65.1-2.mga8
+ Revision: 1534563
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Oct 05 2019 cjw <cjw> 1:65.1-1.mga8
+ Revision: 1449384
- new version 65.1 - new lib major 65
- fix test suite failures
- use docs built from sources
- change download url to github
+ tv <tv>
- ignore testsuite failures on ix86
+ shlomif <shlomif>
- New version 64.2 - new lib major 64.

* Sat Dec 29 2018 luigiwalser <luigiwalser> 1:63.1-1.mga7
+ Revision: 1346076
- 63.1
- library major is now 63

* Sun Sep 23 2018 umeabot <umeabot> 1:62.1-2.mga7
+ Revision: 1298275
- Mageia 7 Mass Rebuild

* Sun Aug 19 2018 tv <tv> 1:62.1-1.mga7
+ Revision: 1252905
- new release

* Fri Jun 01 2018 wally <wally> 1:59.1-6.mga7
+ Revision: 1233511
- fix build with new glibc

* Thu Dec 28 2017 luigiwalser <luigiwalser> 1:59.1-5.mga7
+ Revision: 1186275
- disable flaky tests for now
- library major is 59
- add upstream patch to fix CVE-2017-15422
- add patch from ubuntu to fix CVE-2017-14952
+ tv <tv>
- drop merged patches
- new release

* Thu Apr 20 2017 luigiwalser <luigiwalser> 1:58.2-3.mga6
+ Revision: 1096896
- add upstream patch to fix CVE-2017-7867

* Thu Mar 23 2017 mrambo3501 <mrambo3501> 1:58.2-2.mga6
+ Revision: 1094616
- add icu patches bundled with FF52esr

* Wed Mar 15 2017 mrambo3501 <mrambo3501> 1:58.2-1.mga6
+ Revision: 1092660
- update to 58.2

* Fri Nov 25 2016 luigiwalser <luigiwalser> 1:57.1-3.mga6
+ Revision: 1070160
- add patch from fedora to fix CVE-2016-7415

* Fri Sep 09 2016 luigiwalser <luigiwalser> 1:57.1-2.mga6
+ Revision: 1051051
- add patch from debian to fix CVE-2016-6293

* Thu May 12 2016 luigiwalser <luigiwalser> 1:57.1-1.mga6
+ Revision: 1014258
- add upstream patch to fix CVE-2016-0494
- 57.1
- library major is now 57
- rediff CVE-2015-4760 patch (from ubuntu)
- re-add missing hunk of CVE-2014-6585 patch (from ubuntu)

* Sat Apr 16 2016 akien <akien> 1:56.1-3.mga6
+ Revision: 1002959
- Rebuild for missing RPM signature

* Thu Feb 11 2016 umeabot <umeabot> 1:56.1-2.mga6
+ Revision: 954441
- Mageia 6 Mass Rebuild

* Fri Jan 01 2016 luigiwalser <luigiwalser> 1:56.1-1.mga6
+ Revision: 917503
- 56.1
- library major is now 56
- remove upstreamed CVE-2015-1270 patch (patch 13)

* Wed Sep 30 2015 spuhler <spuhler> 1:55.1-4.mga6
+ Revision: 885434
- rebuild with current g++

* Wed Jul 29 2015 luigiwalser <luigiwalser> 1:55.1-3.mga6
+ Revision: 858774
- add patch from debian to fix CVE-2015-4760

* Sun Jul 26 2015 cjw <cjw> 1:55.1-2.mga6
+ Revision: 857905
- patch13: use patch from chromium 44 to fix CVE-2015-1270

* Fri Jul 24 2015 cjw <cjw> 1:55.1-1.mga6
+ Revision: 856736
- 55.1
- drop patches 7-12: fixed upstream
- add check section

* Tue May 05 2015 luigiwalser <luigiwalser> 1:53.1-12.mga5
+ Revision: 821270
- add upstream patches to fix CVE-2014-814[67] and an integer overflow

* Thu Mar 05 2015 luigiwalser <luigiwalser> 1:53.1-11.mga5
+ Revision: 817819
- add upstream patch to fix CVE-2014-6585 and CVE-2014-6591

* Wed Jan 28 2015 luigiwalser <luigiwalser> 1:53.1-10.mga5
+ Revision: 812587
- add another upstream change related to security issues fixed in chromium

* Tue Jan 27 2015 luigiwalser <luigiwalser> 1:53.1-9.mga5
+ Revision: 812572
- add upstream changes to fix CVE-2014-7923 and CVE-2014-7926

* Wed Nov 26 2014 cjw <cjw> 1:53.1-8.mga5
+ Revision: 799325
- remove duplicate entry in file list of icu package

* Wed Nov 26 2014 cjw <cjw> 1:53.1-7.mga5
+ Revision: 799317
- make icu-config a multiarch binary (mga#13538)

* Wed Oct 15 2014 umeabot <umeabot> 1:53.1-6.mga5
+ Revision: 739067
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1:53.1-5.mga5
+ Revision: 680456
- Mageia 5 Mass Rebuild

* Sun Apr 06 2014 wally <wally> 1:53.1-4.mga5
+ Revision: 612440
- remove icu-data obsoletes now when it's removed from mirrors

* Sun Apr 06 2014 wally <wally> 1:53.1-3.mga5
+ Revision: 612250
- add major to data pkg name to allow multiple ones being installed simultaneously

* Sat Apr 05 2014 wally <wally> 1:53.1-2.mga5
+ Revision: 611792
- loosen lib pkg requires to not defeat the purpose of libification on lib major changes

* Fri Apr 04 2014 fwang <fwang> 1:53.1-1.mga5
+ Revision: 611718
- 53.1

* Mon Oct 21 2013 umeabot <umeabot> 1:52.1-2.mga4
+ Revision: 540925
- Mageia 4 Mass Rebuild

* Thu Oct 10 2013 fwang <fwang> 1:52.1-1.mga4
+ Revision: 494532
- disable check
- update file list
- update file list
- 52.1

* Thu Sep 26 2013 fwang <fwang> 1:52-0.rc2.1.mga4
+ Revision: 486755
- update file list
- new version 52rc2
- strict versioned requires

* Sun May 26 2013 fwang <fwang> 1:51.2-2.mga4
+ Revision: 427922
- tighten req

* Sun May 26 2013 fwang <fwang> 1:51.2-1.mga4
+ Revision: 427906
- new version 51.2

* Thu May 23 2013 fwang <fwang> 1:51.1-1.mga4
+ Revision: 424705
- new version 51.1

* Wed Jan 30 2013 luigiwalser <luigiwalser> 1:50.1.2-1.mga3
+ Revision: 393609
- 50.1.2

* Sat Jan 12 2013 umeabot <umeabot> 1:50.1.1-2.mga3
+ Revision: 354220
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 22 2012 fwang <fwang> 1:50.1.1-1.mga3
+ Revision: 333784
- new version 50.1.1

* Sat Nov 10 2012 fwang <fwang> 1:50.1-5.mga3
+ Revision: 316795
- add upstream real fix

* Fri Nov 09 2012 fwang <fwang> 1:50.1-4.mga3
+ Revision: 316695
- add patch from upstream bug#9717 to disable cxx11

* Thu Nov 08 2012 fwang <fwang> 1:50.1-3.mga3
+ Revision: 316345
- split out data file
- disable renaming form uconfig as suggested

* Thu Nov 08 2012 fwang <fwang> 1:50.1-2.mga3
+ Revision: 316341
- update build switch as sugggested by upstream

* Tue Nov 06 2012 fwang <fwang> 1:50.1-1.mga3
+ Revision: 314716
- new version 50.1

* Fri Jun 08 2012 fwang <fwang> 1:49.1.2-1.mga3
+ Revision: 257499
- new version 49.1.2

* Tue May 29 2012 fwang <fwang> 1:49.1.1-1.mga3
+ Revision: 248933
- new version 49.1.1

* Fri Dec 30 2011 anssi <anssi> 1:4.8.1.1-2.mga2
+ Revision: 188944
- fix CVE-2011-4599 (buffer overflow, patch from rhel6, via Mandriva)

* Sun Nov 27 2011 fwang <fwang> 1:4.8.1.1-1.mga2
+ Revision: 172772
- new version 4.8.1.1

* Fri Sep 02 2011 tv <tv> 1:4.8.1-2.mga2
+ Revision: 137820
- make the huge doc subpackage be noarch
+ fwang <fwang>
- new version 4.8.1

* Mon Jun 20 2011 fwang <fwang> 1:4.8-1.mga2
+ Revision: 110250
- sync patches from mandriva
- new version 4.8
+ rtp <rtp>
- backport fix from upstream ticket 7664 (bad asm syntax)

* Sun Jan 09 2011 blino <blino> 1:4.4.2-2.mga1
+ Revision: 1505
- remove old ldconfig scriptlets
- imported package icu


* Mon Oct 04 2010 Funda Wang <fwang@mandriva.org> 1:4.4.2-1mdv2011.0
+ Revision: 582874
- new version 4.4.2

* Sat Jul 31 2010 Funda Wang <fwang@mandriva.org> 1:4.4.1-1mdv2011.0
+ Revision: 563953
- do not use strict alias patch but use cflags, upstream does not like the patch
- add upstream patch to deal with buffer overflow problem
- revert to 4.4.1 stable

  + Matthew Dawkins <mattydaw@mandriva.org>
    - new version 4.5.1
      patch applied upstream

* Sun Mar 21 2010 Funda Wang <fwang@mandriva.org> 1:4.4-2mdv2010.1
+ Revision: 526037
- install libicutest

* Sat Mar 20 2010 Emmanuel Andry <eandry@mandriva.org> 1:4.4-1mdv2010.1
+ Revision: 525429
- New version 4.4
- New major 44
- rediff p4

  + Funda Wang <fwang@mandriva.org>
    - build 64 bits at first

* Mon Jan 11 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1:4.2.1-2mdv2010.1
+ Revision: 489818
- Patch4: fix build
- really use 4.2.1 tarballs

* Sat Jul 25 2009 Frederik Himpe <fhimpe@mandriva.org> 1:4.2.1-1mdv2010.0
+ Revision: 399844
- update to new version 4.2.1

* Sun May 31 2009 Funda Wang <fwang@mandriva.org> 1:4.2-2mdv2010.0
+ Revision: 381588
- stil use fedora's icu-config

* Sun May 31 2009 Funda Wang <fwang@mandriva.org> 1:4.2-1mdv2010.0
+ Revision: 381575
- New version 4.2

  + Christophe Fergeau <cfergeau@mandriva.com>
    - fix compilation with gcc 4.4

* Tue Jan 20 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1:4.0.1-1mdv2009.1
+ Revision: 331791
- update to new version 4.0.1

* Sun Dec 21 2008 Oden Eriksson <oeriksson@mandriva.com> 1:4.0-3mdv2009.1
+ Revision: 316951
- fix build with -Werror=format-security (P3)
- rebuild

* Wed Jul 16 2008 Funda Wang <fwang@mandriva.org> 1:4.0-2mdv2009.0
+ Revision: 236515
- switch fedora's icu-config for the package's own icu-config breaks too much

* Fri Jul 04 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1:4.0-1mdv2009.0
+ Revision: 231685
- enable epoch :(
- update to new version 4.0 (looks like the versioning has been broken, epoch needed ?)
- fix descriptions
- Patch1: enable build with strict-aliasing
- Patch2: add icu.pc
- add buildrequires on doxygen
- enable checks
- fix file list

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Fri May 30 2008 Funda Wang <fwang@mandriva.org> 4.0.d01-1mdv2009.0
+ Revision: 213349
- New version 4.0.d01

* Sat Jan 26 2008 Funda Wang <fwang@mandriva.org> 3.8.1-2mdv2008.1
+ Revision: 158374
- fix CVE 2007-4770 and 4771

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Dec 14 2007 Funda Wang <fwang@mandriva.org> 3.8.1-1mdv2008.1
+ Revision: 120061
- New version 3.8.1

* Tue Dec 11 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 3.8-2mdv2008.1
+ Revision: 117322
- Added patch setBreakType, which makes that method public, as OOo requires it
  to be.

* Sat Oct 27 2007 Funda Wang <fwang@mandriva.org> 3.8-1mdv2008.1
+ Revision: 102667
- New version 3.8
- New major ( 36 -> 38 )

* Sat Sep 01 2007 Pascal Terjan <pterjan@mandriva.org> 3.6-4mdv2008.0
+ Revision: 77367
- Move icu-config to -devel package and fix it on x86_64

* Sun Jun 24 2007 Funda Wang <fwang@mandriva.org> 3.6-3mdv2008.0
+ Revision: 43594
- adopt to new devel package policy again

* Thu Jun 21 2007 Funda Wang <fwang@mandriva.org> 3.6-2mdv2008.0
+ Revision: 42306
- Really use correct tarball

* Wed Jun 20 2007 Funda Wang <fwang@mandriva.org> 3.6-1mdv2008.0
+ Revision: 41947
- correct tarball name
  remove invalid directory
  adopt to new develname
- New version
- Import icu



* Tue Jan  3 2006 Götz Waschk <waschk@mandriva.org> 3.4-2mdk
- drop devel package obsoletes
- drop prereq
- make the devel package installable

* Tue Jan 03 2006 Oden Eriksson <oeriksson@mandriva.com> 3.4-1mdk
- 3.4
- drop the upstream patch (P0)
- fix deps
- make it rpmbuildupdate aware

* Tue May 10 2005 Arnaud de Lorbeau <devel@mandriva.com> 3.2-2mdk
- Provides icu32-devel

* Tue May 10 2005 Arnaud de Lorbeau <devel@mandriva.com> 3.2-1mdk
- 3.2

* Mon Jun  7 2004 Götz Waschk <waschk@linux-mandrake.com> 2.8.d01-3mdk
- rebuild

* Fri Jun 04 2004 Marcel Pol <mpol@mandrake.org> 2.8.d01-2mdk
- rebuild

* Wed Dec 17 2003 Marcel Pol <mpol@mandrake.org> 2.8.d01-1mdk
- major is 28
- From Quel Qun <kelk1@hotmail.com>
    - Mandrake package.
